aboutsummaryrefslogtreecommitdiff
path: root/gold/archive.h
diff options
context:
space:
mode:
Diffstat (limited to 'gold/archive.h')
-rw-r--r--gold/archive.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/gold/archive.h b/gold/archive.h
index fb83ea6..0dfaf92 100644
--- a/gold/archive.h
+++ b/gold/archive.h
@@ -117,10 +117,11 @@ class Archive
void
read_armap(off_t start, section_size_type size);
// Read an archive member header at OFF. Return the size of the
// member, and set *PNAME to the name.
off_t
- read_header(off_t off, std::string* pname);
+ read_header(off_t off, bool cache, std::string* pname);
// Interpret an archive header HDR at OFF. Return the size of the
// member, and set *PNAME to the name.
@@ -117,10 +117,11 @@ class Archive
void
read_armap(off_t start, section_size_type size);
- // Read an archive member header at OFF. Return the size of the
- // member, and set *PNAME to the name.
+ // Read an archive member header at OFF. CACHE is whether to cache
+ // the file view. Return the size of the member, and set *PNAME to
+ // the name.
off_t